pub enum CompareFunction {
Less,
LessEqual,
Greater,
GreaterEqual,
Equal,
NotEqual,
Always,
Never,
}Expand description
Optional depth-compare function for shadow/depth sampling.
Variants
Less
Passes when the sampled value is less than the reference.
LessEqual
Passes when the sampled value is less than or equal to the reference.
Greater
Passes when the sampled value is greater than the reference.
GreaterEqual
Passes when the sampled value is greater than or equal to the reference.
Equal
Passes when the sampled value equals the reference.
NotEqual
Passes when the sampled value differs from the reference.
Always
Always passes.
Never
Never passes.